@@ -11,7 +11,7 @@ import pkg_resources
 
 __package_name__ = 'KGlobal'
 __author__ = 'Kevin Russell'
-__version__ = "1.3.5"
+__version__ = "1.4.0"
 __description__ = '''File, encryption, SQL, XML, and etc...'''
 __url__ = 'https://github.com/KLRussell/Python_KGlobal_Package'
 
@@ -44,7 +44,7 @@ def create_pepper(filepath=None):
     if filepath and os.path.exists(os.path.dirname(filepath)):
         if not os.path.isfile(filepath):
             raise ValueError("'filepath' is not a file")
-        if os.path.splitext(filepath)[1] != '.key':
+        if os.path.splitext(filepath) != '.key':
             raise ValueError("'filepath' is not a .key extension!")
 
         pepper_fp = filepath
