@@ -33,9 +33,10 @@ class SG(Tk):
         if salt_key_path and not os.path.exists(salt_key_path):
             salt_key_path = os.path.dirname(salt_key_path)
 
-        if pepper_key_path and os.path.exists(default_pepper_filepath()):
+        if not pepper_key_path and os.path.exists(default_pepper_filepath()):
             self.__pepper_key = default_pepper_filepath()
-        else:
+
+        if not pepper_key_path:
             raise ValueError("'pepper_key_path' does not exist or wasn't populated. Please specify a pepper key filepath or create a new pepper key (KGlobal -c <dir (optional)>)")
 
         self.__pointer = pointer
