@@ -9,7 +9,7 @@ from exchangelib.errors import UnauthorizedError, TransportError
 import pathlib as pl
 
 
-class TB(SQLQueue, LogHandle):
+class TBoxBase(object):
     """
     A toolbox instance class that combines SQLQueue class, LogHandle class, and other various tools for use
     """
@@ -18,7 +18,7 @@ class TB(SQLQueue, LogHandle):
     __main_config = None
     __pointer = None
 
-    def __init__(self, script_path, max_pool_size, pepper_key_fp, logging_path, logging_base_name):
+    def __init__(self, script_path, pepper_key_fp=None):
         """
         Lets setup SQLQueue, Logging, Main Config, and Local Config
 
@@ -28,20 +28,6 @@ class TB(SQLQueue, LogHandle):
         :param max_pool_size: (Optional) SQL max poolsize for connection queue
         """
 
-        if logging_path and os.path.exists(logging_path) and os.path.isdir(logging_path):
-            file_dir = logging_path
-
-            if logging_base_name:
-                base_name = os.path.basename(logging_base_name)
-            else:
-                base_name = os.path.basename(script_path)
-        else:
-            file_dir = None
-            base_name = None
-
-        SQLQueue.__init__(self, pool_size=max_pool_size)
-        LogHandle.__init__(self, file_dir=file_dir, base_name=base_name)
-
         from . import default_pepper_filepath
         from .data import DataConfig
 
@@ -138,6 +124,56 @@ class TB(SQLQueue, LogHandle):
         else:
             self.__pointer = pointer
 
+    def __new_pointer(self, pointer=None, old_key_path=None, old_db_path=None):
+        from .setup_gui import SetupGUI
+
+        obj = SetupGUI(local_db_dir=self.__base_dir, pointer=pointer, pepper_key_path=self.__pepper_key_fp,
+                       salt_key_path=old_key_path, main_db_path=old_db_path)
+
+        if obj.pointer:
+            self.pointer = obj.pointer
+
+    def __set_config(self):
+        if self.__pointer:
+            from .data import DataConfig
+
+            key = self.__pointer['Key_Path']
+            main_db = self.__pointer['Main_DB_Path']
+            local_db = self.__pointer['Local_DB_Path']
+
+            local_file_name_prefix = os.path.splitext(os.path.basename(local_db.decrypt()))
+            main_file_name_prefix = os.path.splitext(os.path.basename(main_db.decrypt()))
+            self.__local_config = DataConfig(file_dir=os.path.dirname(local_db.decrypt()),
+                                             file_name_prefix=local_file_name_prefix[0],
+                                             file_ext=local_file_name_prefix[1].replace('.', ''),
+                                             salt_key_fp=key.decrypt(), new_salt_key=False, encrypt=True)
+            self.__main_config = DataConfig(file_dir=os.path.dirname(main_db.decrypt()),
+                                            file_name_prefix=main_file_name_prefix[0],
+                                            file_ext=main_file_name_prefix[1].replace('.', ''),
+                                            salt_key_fp=key.decrypt(), new_salt_key=False, encrypt=True)
+
+    def __del__(self):
+        SQLQueue.__del__(self)
+        LogHandle.__del__(self)
+
+class Toolbox(TBoxBase, LogHandle, SQLQueue):
+    def __init__(self, script_path, pepper_key_fp=None, logging_dir=None, logging_base_name=None, max_pool_size=None,
+                 *args, **kwargs):
+        if logging_dir and os.path.exists(logging_dir) and os.path.isdir(logging_dir):
+            file_dir = logging_dir
+
+            if logging_base_name:
+                base_name = os.path.basename(logging_base_name)
+            else:
+                base_name = os.path.basename(script_path)
+        else:
+            file_dir = None
+            base_name = None
+
+        TBoxBase.__init__(self, script_path=script_path, pepper_key_fp=pepper_key_fp)
+        SQLQueue.__init__(self, max_pool_size=max_pool_size)
+        LogHandle.__init__(self, file_dir=file_dir, base_name=base_name)
+
     def config_sql_conn(self, sql_config):
         """
         Create a custom SQL connection and add engine to SQL queue pool
@@ -311,45 +347,4 @@ class TB(SQLQueue, LogHandle):
 
         for engine in self.pool_list:
             if isinstance(engine, SQLEngineClass) and engine.sql_config == config:
-                return engine
-
-    def __new_pointer(self, pointer=None, old_key_path=None, old_db_path=None):
-        from .setup_gui import SetupGUI
-
-        obj = SetupGUI(local_db_dir=self.__base_dir, pointer=pointer, pepper_key_path=self.__pepper_key_fp,
-                       salt_key_path=old_key_path, main_db_path=old_db_path)
-
-        if obj.pointer:
-            self.pointer = obj.pointer
-
-    def __set_config(self):
-        if self.__pointer:
-            from .data import DataConfig
-
-            key = self.__pointer['Key_Path']
-            main_db = self.__pointer['Main_DB_Path']
-            local_db = self.__pointer['Local_DB_Path']
-
-            local_file_name_prefix = os.path.splitext(os.path.basename(local_db.decrypt()))
-            main_file_name_prefix = os.path.splitext(os.path.basename(main_db.decrypt()))
-            self.__local_config = DataConfig(file_dir=os.path.dirname(local_db.decrypt()),
-                                             file_name_prefix=local_file_name_prefix[0],
-                                             file_ext=local_file_name_prefix[1].replace('.', ''),
-                                             salt_key_fp=key.decrypt(), new_salt_key=False, encrypt=True)
-            self.__main_config = DataConfig(file_dir=os.path.dirname(main_db.decrypt()),
-                                            file_name_prefix=main_file_name_prefix[0],
-                                            file_ext=main_file_name_prefix[1].replace('.', ''),
-                                            salt_key_fp=key.decrypt(), new_salt_key=False, encrypt=True)
-
-    def __del__(self):
-        SQLQueue.__del__(self)
-        LogHandle.__del__(self)
-
-
-class Toolbox(TB):
-    SQL_POOLSIZE = 10
-
-    def __init__(self, script_path, max_pool_size=SQL_POOLSIZE, pepper_key_fp=None, logging_path=None,
-                 logging_base_name=None):
-        TB.__init__(self, script_path=script_path, max_pool_size=max_pool_size, pepper_key_fp=pepper_key_fp,
-                    logging_path=logging_path, logging_base_name=logging_base_name)
\ No newline at end of file
+                return engine
\ No newline at end of file
